#[repr(u8)]pub enum BuiltinNrc {
Show 40 variants
GeneralReject = 16,
ServiceNotSupported = 17,
SubFunctionNotSupported = 18,
IncorrectMessageLengthOrInvalidFormat = 19,
ResponseTooLong = 20,
BusyRepeatRequest = 33,
ConditionsNotCorrect = 34,
RequestSequenceError = 36,
NoResponseFromSubnetComponent = 37,
FailurePreventsExecutionOfRequestedAction = 38,
RequestOutOfRange = 49,
SecurityAccessDenied = 51,
InvalidKey = 53,
ExceededNumberOfAttempts = 54,
RequiredTimeDelayNotExpired = 55,
UploadDownloadNotAccepted = 112,
TransferDataSuspended = 113,
GeneralProgrammingFailure = 114,
WrongBlockSequenceCounter = 115,
ResponsePending = 120,
SubFunctionNotSupportedInActiveSession = 126,
ServiceNotSupportedInActiveSession = 127,
RpmTooHigh = 129,
RpmTooLow = 130,
EngineIsRunning = 131,
EngineIsNotRunning = 132,
EngineRunTimeTooLow = 133,
TemperatureTooHigh = 134,
TemperatureTooLow = 135,
VehicleSpeedTooHigh = 136,
VehicleSpeedToLow = 137,
ThrottlePedalTooHigh = 138,
ThrottlePedalTooLow = 139,
TransmissionRangeNotInNeutral = 140,
TransmissionRangeNotInGear = 141,
BrakeSwitchesNotClosed = 143,
ShifterLevelNotInPark = 144,
TorqueConverterClutchLocked = 145,
VoltageTooHigh = 146,
VoltageTooLow = 147,
}Expand description
A built-in NRC type covering all codes the server may emit.
Applications that do not need a custom error type may use this directly as type Error = BuiltinNrc in the ServerHandler impl.
Variants
GeneralReject = 16
ServiceNotSupported = 17
SubFunctionNotSupported = 18
IncorrectMessageLengthOrInvalidFormat = 19
ResponseTooLong = 20
BusyRepeatRequest = 33
ConditionsNotCorrect = 34
RequestSequenceError = 36
NoResponseFromSubnetComponent = 37
FailurePreventsExecutionOfRequestedAction = 38
RequestOutOfRange = 49
SecurityAccessDenied = 51
InvalidKey = 53
ExceededNumberOfAttempts = 54
RequiredTimeDelayNotExpired = 55
UploadDownloadNotAccepted = 112
TransferDataSuspended = 113
GeneralProgrammingFailure = 114
WrongBlockSequenceCounter = 115
ResponsePending = 120
SubFunctionNotSupportedInActiveSession = 126
ServiceNotSupportedInActiveSession = 127
RpmTooHigh = 129
RpmTooLow = 130
EngineIsRunning = 131
EngineIsNotRunning = 132
EngineRunTimeTooLow = 133
TemperatureTooHigh = 134
TemperatureTooLow = 135
VehicleSpeedTooHigh = 136
VehicleSpeedToLow = 137
ThrottlePedalTooHigh = 138
ThrottlePedalTooLow = 139
TransmissionRangeNotInNeutral = 140
TransmissionRangeNotInGear = 141
BrakeSwitchesNotClosed = 143
ShifterLevelNotInPark = 144
TorqueConverterClutchLocked = 145
VoltageTooHigh = 146
VoltageTooLow = 147