pub trait NrcError: Into<u8> + Debug {
Show 40 methods
// Required methods
fn general_reject() -> Self;
fn service_not_supported() -> Self;
fn sub_function_not_supported() -> Self;
fn incorrect_message_length_or_invalid_format() -> Self;
fn response_too_long() -> Self;
fn busy_repeat_request() -> Self;
fn conditions_not_correct() -> Self;
fn request_sequence_error() -> Self;
fn no_response_from_subnet_component() -> Self;
fn failure_prevents_execution_of_requested_action() -> Self;
fn request_out_of_range() -> Self;
fn security_access_denied() -> Self;
fn invalid_key() -> Self;
fn exceeded_number_of_attempts() -> Self;
fn required_time_delay_not_expired() -> Self;
fn upload_download_not_accepted() -> Self;
fn transfer_data_suspended() -> Self;
fn general_programming_failure() -> Self;
fn wrong_block_sequence_counter() -> Self;
fn response_pending() -> Self;
fn sub_function_not_supported_in_active_session() -> Self;
fn service_not_supported_in_active_session() -> Self;
fn rpm_too_high() -> Self;
fn rpm_too_low() -> Self;
fn engine_is_running() -> Self;
fn engine_is_not_running() -> Self;
fn engine_run_time_too_low() -> Self;
fn temperature_too_high() -> Self;
fn temperature_too_low() -> Self;
fn vehicle_speed_too_high() -> Self;
fn vehicle_speed_too_low() -> Self;
fn throttle_pedal_too_high() -> Self;
fn throttle_pedal_too_low() -> Self;
fn transmission_range_not_in_neutral() -> Self;
fn transmission_range_not_in_gear() -> Self;
fn brake_switches_not_closed() -> Self;
fn shifter_level_not_in_park() -> Self;
fn torque_converter_clutch_locked() -> Self;
fn voltage_too_high() -> Self;
fn voltage_too_low() -> Self;
}Expand description
A trait for application error types that can be converted into UDS Negative Response Codes (NRCs).
The server state machine uses this to construct NRC responses without knowing the application’s
error type internals. The application defines the mapping via Into<u8>.
Required Methods
Sourcefn general_reject() -> Self
fn general_reject() -> Self
0x10 - general reject
Sourcefn service_not_supported() -> Self
fn service_not_supported() -> Self
0x11 - serviceNotSupported
Sourcefn sub_function_not_supported() -> Self
fn sub_function_not_supported() -> Self
0x12 - subFunctionNotSupported
Sourcefn incorrect_message_length_or_invalid_format() -> Self
fn incorrect_message_length_or_invalid_format() -> Self
0x13 - incorrectMessageLengthOrInvalidFormat
Sourcefn response_too_long() -> Self
fn response_too_long() -> Self
0x14 - response too long
Sourcefn busy_repeat_request() -> Self
fn busy_repeat_request() -> Self
0x21 - busy repeat request
Sourcefn conditions_not_correct() -> Self
fn conditions_not_correct() -> Self
0x22 - conditionsNotCorrect
Sourcefn request_sequence_error() -> Self
fn request_sequence_error() -> Self
0x24 - requestSequenceError
Sourcefn no_response_from_subnet_component() -> Self
fn no_response_from_subnet_component() -> Self
0x25 - no response from subnet component
Sourcefn failure_prevents_execution_of_requested_action() -> Self
fn failure_prevents_execution_of_requested_action() -> Self
0x26 - failure prevents execution of requested action
Sourcefn request_out_of_range() -> Self
fn request_out_of_range() -> Self
0x31 - requestOutOfRange
Sourcefn security_access_denied() -> Self
fn security_access_denied() -> Self
0x33 - securityAccessDenied
Sourcefn invalid_key() -> Self
fn invalid_key() -> Self
0x35 - invalidKey
Sourcefn exceeded_number_of_attempts() -> Self
fn exceeded_number_of_attempts() -> Self
0x36 - exceededNumberOfAttempts
Sourcefn required_time_delay_not_expired() -> Self
fn required_time_delay_not_expired() -> Self
0x37 - requiredTimeDelayNotExpired
Sourcefn upload_download_not_accepted() -> Self
fn upload_download_not_accepted() -> Self
0x70 - uploadDownloadNotAccepted
Sourcefn transfer_data_suspended() -> Self
fn transfer_data_suspended() -> Self
0x71 - transferDataSuspended
Sourcefn general_programming_failure() -> Self
fn general_programming_failure() -> Self
0x72 - generalProgrammingFailure
Sourcefn wrong_block_sequence_counter() -> Self
fn wrong_block_sequence_counter() -> Self
0x73 - wrongBlockSequenceCounter
Sourcefn response_pending() -> Self
fn response_pending() -> Self
0x78 - requestCorrectlyReceivedResponsePending
Sourcefn sub_function_not_supported_in_active_session() -> Self
fn sub_function_not_supported_in_active_session() -> Self
0x7E - subFunctionNotSupportedInActiveSession
Sourcefn service_not_supported_in_active_session() -> Self
fn service_not_supported_in_active_session() -> Self
0x7F - serviceNotSupportedInActiveSession
Sourcefn rpm_too_high() -> Self
fn rpm_too_high() -> Self
0x81 - rpmTooHigh
Sourcefn rpm_too_low() -> Self
fn rpm_too_low() -> Self
0x82 - rpmTooLow
Sourcefn engine_is_running() -> Self
fn engine_is_running() -> Self
0x83 - engineIsRunning
Sourcefn engine_is_not_running() -> Self
fn engine_is_not_running() -> Self
0x84 - engineIsNotRunning
Sourcefn engine_run_time_too_low() -> Self
fn engine_run_time_too_low() -> Self
0x85 - engineRunTimeTooLow
Sourcefn temperature_too_high() -> Self
fn temperature_too_high() -> Self
0x86 - temperatureTooHigh
Sourcefn temperature_too_low() -> Self
fn temperature_too_low() -> Self
0x87 - temperatureTooLow
Sourcefn vehicle_speed_too_high() -> Self
fn vehicle_speed_too_high() -> Self
0x88 - vehicleSpeedTooHigh
Sourcefn vehicle_speed_too_low() -> Self
fn vehicle_speed_too_low() -> Self
0x89 - vehicleSpeedTooLow
Sourcefn throttle_pedal_too_high() -> Self
fn throttle_pedal_too_high() -> Self
0x8A - throttlePedalTooHigh
Sourcefn throttle_pedal_too_low() -> Self
fn throttle_pedal_too_low() -> Self
0x8B - throttlePedalTooLow
Sourcefn transmission_range_not_in_neutral() -> Self
fn transmission_range_not_in_neutral() -> Self
0x8C - transmissionRangeNotInNeutral
Sourcefn transmission_range_not_in_gear() -> Self
fn transmission_range_not_in_gear() -> Self
0x8D - transmissionRangeNotInGear
Sourcefn brake_switches_not_closed() -> Self
fn brake_switches_not_closed() -> Self
0x8F - brakeSwitchesNotClosed
Sourcefn shifter_level_not_in_park() -> Self
fn shifter_level_not_in_park() -> Self
0x90 - shifterLevelNotInPark
Sourcefn torque_converter_clutch_locked() -> Self
fn torque_converter_clutch_locked() -> Self
0x91 - torqueConverterClutchLocked
Sourcefn voltage_too_high() -> Self
fn voltage_too_high() -> Self
0x92 - voltageTooHigh
Sourcefn voltage_too_low() -> Self
fn voltage_too_low() -> Self
0x93 - voltageTooLow
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".